/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */

 




package org.greenstone.gatherer;
/**************************************************************************************
 * Title:        Gatherer
 * Description:  The Gatherer: a tool for gathering and enriching a digital collection.
 * Copyright:    Copyright (c) 2001
 * Company:      The University of Waikato
 * Written:        /  /01
 * Revised:      28/05/01
 **************************************************************************************/
import java.util.Date;
import java.util.Random;
/** Provides an event-type wrapper around a message for displaying to the user.
* @author John Thompson, Greenstone Digital Library, University of Waikato
* @version 2.1
*/
public class Message {
	 /** The level of this message. See above. */
	 public int level;
	 /** The source of this message. See above. */
	 public int source;
	 /** The age of this message. Used for ordering. */
	 public long time;
	 /** The actual message content of this message. */
	 public String message;
	 /** Used to indicate the source of the message is anywhere in general. */
	 static final public int GENERAL   = 0;
	 /** Used to indicate the source of the message is the browsing methods. */
	 static final public int BROWSER   = 1;
	 /** Used to indicate the source of the message is the mirroring methods. */
	 static final public int MIRRORING = 2;
	 /** Used to indicate the source of the message is the file collection methods. */
	 static final public int COLLECT   = 3;
	 /** Used to indicate the source of the message is the metadata and set methods. */
	 static final public int METAEDIT  = 4;
	 /** Used to indicate the source of the message is the building methods. */
	 static final public int BUILDING  = 5;
	 /** Used to indicate the source of the message is the preview methods. */
	 static final public int FINAL     = 6;
	 /** Used to indicate the source of the message is the log itself. */
	 static final public int LOG       = 7;
	 /** Used to indicate the level of the message is Main. */
	 static final public int MAIN = 0;
	 /** Used to indicate the level of the message is Event. */
	 static final public int EVENT = 1;
	 /** Used to indicate the level of the message is Information. */
	 static final public int INFO = 2;
	 /** Used to indicate the level of the message is Error. */
	 static final public int ERROR = 3;

	 /**
	  * Creates a new message.
	  * @param source the source of this message as an <i>int</i>. See above.
	  * @param level the level of this message as an <i>int</i>. See above.
	  * @param message the message content of this message as a <strong>String</strong>.
	  */
	 public Message(int source, int level, String message) {
		  this.level = level;
		  this.source = source;
		  time = (new Date()).getTime();
		  this.message = message;
	 }
	 /**
	  * Used to display a message, stating level and source.
	  * @param gatherer the main <strong>Gatherer</strong> class, used to get at the Dictionary.
	  * @see org.greenstone.gatherer.Dictionary
	  */
	 public String toString(Gatherer gatherer) {
		  String source_str = "";
		  switch(source) {
		  case GENERAL:
				source_str = gatherer.dictionary.get("Source.General");
				break;
		  case BROWSER:
				source_str = gatherer.dictionary.get("Source.Browser");
				break;
		  case MIRRORING:
				source_str = gatherer.dictionary.get("Source.Mirroring");
				break;
		  case COLLECT:
				source_str = gatherer.dictionary.get("Source.Collect");
				break;
		  case METAEDIT:
				source_str = gatherer.dictionary.get("Source.MetaEdit");
				break;
		  case BUILDING:
				source_str = gatherer.dictionary.get("Source.Building");
				break;
		  default:
				source_str = gatherer.dictionary.get("Source.Unknown");
		  }

		  String level_str = "";
		  switch(level) {
		  case MAIN:
				level_str = gatherer.dictionary.get("Level.Main");
				break;
		  case EVENT:
				level_str = gatherer.dictionary.get("Level.Event");
				break;
		  case INFO:
				level_str = gatherer.dictionary.get("Level.Information");
				break;
		  case ERROR:
				level_str = gatherer.dictionary.get("Level.Error");
				break;
		  default:
				level_str = gatherer.dictionary.get("Level.Unknown");
		  }
		  return source_str + " " + level_str + " > " + message;
	 }
	/** Used during testing testing to generate a random message.
	* @return A new <strong>Message</strong> object which has a random source, level and a message body of the current system time.
	*/
	 static public Message random() {
		  Random generator = new Random();
		  int s = generator.nextInt(6);
		  int l = generator.nextInt(4);
		  String m = new Long(System.currentTimeMillis()).toString();
		  return new Message(s,l,m);
	 }
}
